@@ -18,9 +18,12 @@ case "$1" in
 esac;
 
 case "$1" in
-	moto|maemo|zaurus_640x480|zaurus_240x320|pma400)
+	maemo|zaurus_640x480|zaurus_240x320|pma400)
 		menubar_file=data/default/menubar.xml
 		;;
+	moto)
+		menubar_file=data/default/menubar.moto.xml
+		;;
 	*)
 		;;
 esac;
