@@ -34,7 +34,6 @@
 
 #include "../bookmodel/BookModel.h"
 #include "../optionsDialog/OptionsDialog.h"
-#include "../collection/BookList.h"
 
 FBAction::FBAction(FBReader &fbreader) : myFBReader(fbreader) {
 }
@@ -46,11 +45,11 @@ bool ModeDependentAction::isVisible() {
 	return fbreader().getMode() & myVisibleInModes;
 }
 
-ShowCollectionAction::ShowCollectionAction(FBReader &fbreader) : ModeDependentAction(fbreader, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE | FBReader::RECENT_BOOKS_MODE) {
+SetModeAction::SetModeAction(FBReader &fbreader, FBReader::ViewMode modeToSet, int visibleInModes) : ModeDependentAction(fbreader, visibleInModes), myModeToSet(modeToSet) {
 }
 
-void ShowCollectionAction::run() {
-	fbreader().setMode(FBReader::BOOK_COLLECTION_MODE);
+void SetModeAction::run() {
+	fbreader().setMode(myModeToSet);
 }
 
 ShowHelpAction::ShowHelpAction(FBReader &fbreader) : FBAction(fbreader) {
@@ -70,13 +69,6 @@ void ShowHelpAction::run() {
 	}
 }
 
-ShowRecentBooksListAction::ShowRecentBooksListAction(FBReader &fbreader) : ModeDependentAction(fbreader, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE) {
-}
-
-void ShowRecentBooksListAction::run() {
-	fbreader().setMode(FBReader::RECENT_BOOKS_MODE);
-}
-
 ShowOptionsDialogAction::ShowOptionsDialogAction(FBReader &fbreader) : FBAction(fbreader) {
 }
 
@@ -111,8 +103,9 @@ void AddBookAction::run() {
 	FBFileHandler handler;
 	if (ZLDialogManager::instance().selectionDialog(ZLResourceKey("addFileDialog"), handler)) {
 		BookDescriptionPtr description = handler.description();
-		if (!description.isNull() && fbreader().runBookInfoDialog(description->fileName())) {
-			BookList().addFileName(description->fileName());
+		const std::string &fileName = description->fileName();
+		if (!description.isNull() && fbreader().runBookInfoDialog(fileName)) {
+			fbreader().openFile(fileName);
 			fbreader().setMode(FBReader::BOOK_TEXT_MODE);
 		}
 	}
@@ -143,7 +136,10 @@ ShowBookInfoAction::ShowBookInfoAction(FBReader &fbreader) : ModeDependentAction
 }
 
 void ShowBookInfoAction::run() {
-	fbreader().runBookInfoDialog(fbreader().myModel->fileName());
+	const std::string &fileName = fbreader().myModel->fileName();
+	if (fbreader().runBookInfoDialog(fileName)) {
+		fbreader().openFile(fileName);
+	}
 }
 
 UndoAction::UndoAction(FBReader &fbreader) : FBAction(fbreader) {
