@@ -94,11 +94,14 @@ private:
 	int myVisibleInModes;
 };
 
-class ShowCollectionAction : public ModeDependentAction {
+class SetModeAction : public ModeDependentAction {
 
 public:
-	ShowCollectionAction(FBReader &fbreader);
+	SetModeAction(FBReader &fbreader, FBReader::ViewMode modeToSet, int visibleInModes);
 	void run();
+
+private:
+	FBReader::ViewMode myModeToSet;
 };
 
 class ShowHelpAction : public FBAction {
@@ -108,13 +111,6 @@ public:
 	void run();
 };
 
-class ShowRecentBooksListAction : public ModeDependentAction {
-
-public:
-	ShowRecentBooksListAction(FBReader &fbreader);
-	void run();
-};
-
 class ShowOptionsDialogAction : public FBAction {
 
 public:
@@ -201,6 +197,15 @@ public:
 	SearchAction(FBReader &fbreader);
 	bool isVisible();
 	void run();
+
+private:
+	ZLBooleanOption SearchBackwardOption;
+	ZLBooleanOption SearchIgnoreCaseOption;
+	ZLBooleanOption SearchInWholeTextOption;
+	ZLBooleanOption SearchThisSectionOnlyOption;
+	ZLStringOption SearchPatternOption;
+
+friend class SearchPatternEntry;
 };
 
 class FindNextAction : public FBAction {
