@@ -24,6 +24,9 @@
 
 class OEBPlugin : public FormatPlugin {
 
+public:
+	static std::string opfFileName(const std::string &oebFileName);
+
 public:
 	~OEBPlugin();
 	bool providesMetaInfo() const;
@@ -31,9 +34,6 @@ public:
 	bool readDescription(const std::string &path, BookDescription &description) const;
 	bool readModel(const BookDescription &description, BookModel &model) const;
 	const std::string &iconName() const;
-
-private:
-	std::string opfFileName(const std::string &oebFileName) const;
 };
 
 #endif /* __OEBPLUGIN_H__ */
