@@ -22,9 +22,18 @@
 #include "Migration.h"
 #include "migrate.h"
 
-void migrateFromOldVersions() {
+MigrationRunnable::MigrationRunnable() :
+	myVersionOption(FBCategoryKey::SYSTEM, "Version", "FBReaderVersion", "0") {
+}
+
+bool MigrationRunnable::shouldMigrate() const {
+	return myVersionOption.value() < VERSION;
+}
+
+void MigrationRunnable::run() {
 	Migration_0_8_11().doMigration();
 	Migration_0_8_13().doMigration();
+	Migration_0_8_16().doMigration();
 
-	ZLStringOption(FBCategoryKey::SYSTEM, "Version", "FBReaderVersion", "0").setValue(VERSION);
+	myVersionOption.setValue(VERSION);
 }
